package net.wanji.opt.controllerv2.judgeanalysis;

import net.wanji.common.framework.Constants;
import net.wanji.common.framework.dubbointerface.BaseDubboInterface;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.common.framework.rest.AbstractRestServer;
import net.wanji.common.framework.dubbointerface.BaseDubboInterface;
import net.wanji.common.framework.exception.DubboProviderException;
import net.wanji.common.framework.i18n.I18nResourceBundle;
import net.wanji.common.framework.rest.AbstractRestServer;
import net.wanji.common.framework.rest.impl.AbstractRestServerImpl;
import net.wanji.opt.servicev2.judgeanalysis.BaseAreaInfoService;
import net.wanji.opt.entity.judgeanalysis.BaseAreaInfo;
import net.wanji.common.framework.rest.Page;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiImplicitParam;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.google.common.collect.Maps;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import javax.ws.rs.core.MediaType;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 区域基础信息 接口API
 * </p>
 *  @version 1.0
 * @author wangtao
 * @Date 2025-03-18
 */
@RestController
@Slf4j
@RequestMapping("/base-area-info")
@Api(value="BaseAreaInfoController", description="区域基础信息接口", tags = "区域基础信息")
public class BaseAreaInfoController extends AbstractRestServerImpl<BaseAreaInfo> implements AbstractRestServer<BaseAreaInfo>{

    @Autowired
    private BaseAreaInfoService baseAreaInfoService;

    @Override
    public BaseAreaInfoService getBaseDubboInterface() {
        return this.baseAreaInfoService;
    }


    /**
    * 获取所有区域基础信息记录
    *
    * @return JsonViewObject
    */
    @ApiOperation(value = "区域基础信息-获取所有记录", notes = "获取所有区域基础信息记录", response = BaseAreaInfo.class, produces = MediaType.APPLICATION_JSON,hidden = true)
    @GetMapping(value = "/byAll", produces = MediaType.APPLICATION_JSON)
    @Override
    public JsonViewObject getAll() {
        JsonViewObject jsonView = JsonViewObject.newInstance();
        long start=System.currentTimeMillis();

        try {
            List<BaseAreaInfo> list = this.getBaseDubboInterface().findAll();
            jsonView.success(list);
        } catch (DubboProviderException e) {
            jsonView.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("{} getAll error", this.getClass().getSimpleName(), e);
        }
            return jsonView;
    }


    /**
    * 根据id查询区域基础信息记录
    *
    * @param id
    * @return JsonViewObject
    */
    @ApiOperation(value = "区域基础信息-根据id查询记录", notes = "根据id查询区域基础信息记录", response = BaseAreaInfo.class, produces = MediaType.APPLICATION_JSON,hidden = true)
    @GetMapping(value = "/{id}", produces = MediaType.APPLICATION_JSON)
    @Override
    public JsonViewObject getById(@PathVariable String id) {
        JsonViewObject jsonView = JsonViewObject.newInstance();
        long start=System.currentTimeMillis();

        try {
            BaseAreaInfo entity = this.getBaseDubboInterface().findById(id);
            jsonView.success(entity);
        } catch (DubboProviderException e) {
            jsonView.fail(I18nResourceBundle.getConstants("GET_FAILED_MSG"));
            log.error("AbstractRestServerImpl getById error, id:{}", id, e);
        }
        return jsonView;
    }

    @ApiOperation(value = "区域基础信息-根据条件查询记录", notes = "根据条件查询记录", consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/byCondition", produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @Override
    public JsonViewObject getByWhere(@RequestBody BaseAreaInfo entity) {
        return  super.getByWhere(entity);
    }

    @ApiOperation(value = "区域基础信息-根据条件分页查询记录", notes = "根据条件分页查询记录",  produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON,hidden = true)
    @PostMapping(value = "/byPage", produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ResponseBody
    public  JsonViewObject getPage(@RequestBody Page<BaseAreaInfo> page){
        return  super.getPage(page);
    }


    /**
    * 根据id删除
    *
    * @param ids
    * @return JsonViewObject
    */
    @ApiOperation(value = "区域基础信息-根据多个id删除记录", notes = "根据多个id删除记录", response = JsonViewObject.class, produces = MediaType.APPLICATION_JSON ,hidden = true)
    @ApiImplicitParams(value = {
    @ApiImplicitParam(paramType = "query", name = "ids", dataType = "String", required = true, value = "多个记录id，用逗号分隔", example = "1,2")
    })
    @GetMapping(value = "/deleting", produces = MediaType.APPLICATION_JSON)
    public JsonViewObject deleteByIds(String ids) {
         return  super.deleteByIds(ids);
    }

    /**
    * 新建记录
    *
    * @param entity
    * @return JsonViewObject
    */
    @ApiOperation(value = "区域基础信息-新建记录", notes = "新建记录", response = JsonViewObject.class, produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON,hidden = true)
    @PostMapping(value = "/creating", produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public JsonViewObject save( @RequestBody BaseAreaInfo entity){
        return  super.save(entity);
    }

    /**
    * 修改记录
    *
    * @param entity
    * @return
    */
    @ApiOperation(value = "区域基础信息-修改记录", notes = "修改记录", response = JsonViewObject.class, produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON,hidden = true)
    @PostMapping(value = "/updating", produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    public  JsonViewObject update(@RequestBody BaseAreaInfo entity){
        return  super.update(entity);
    }

}
